Introduction — django-inviteme-form v1.0a documentation

### Navigation

- index
- next |
- django-inviteme-form v1.0a documentation »

# Introduction

Django-inviteme provides a simple contact form that only hits the database after the user confirm her email address. It sends threaded emails to avoid response blocking.

- Demo prpject
  - Demo quick setup
  - Email settings
  - Register a signal receiver
- Tutorial
  - Configuration
  - Workflow
  - Signals and receivers
- Signals
  - Confirmation will be requested
  - Confirmation has been requested
  - Confirmation has been received
- Templatetags
  - `render_contact_form`
- Settings
  - `INVITEME_SALT`
  - `INVITEME_NOTIFY_TO`
- Templates

# Quick start

1. Add `inviteme` to `INSTALLED_APPS`.
2. Add `url(r'^invite/', include('inviteme.urls'))` to your root URLconf.
3. `syncdb`, `runserver`, and
4. Hit http://localhost:8000/invite/ in your browser!

# Workflow in short

The user...

1. Clicks on the request an invitation link of your site.
2. She types her email address and clicks on request.
3. Then Django-Inviteme:

> 1. Creates a token with the form data.
> 2. Sends an email to her with a confirmation URL containing the token.

1. She receives the email, she opens it, and she clicks on the confirmation link.
2. Then Django-Inviteme:

> 1. Check that the token is correct and creates a `ContactEmail` model instance.
> 2. Sends an email to `INVITEME_NOTIFY_TO` addresses notifying that a new contact email has arrived.
> 3. And shows a template being grateful to her for the message.

Read a longer workflow description in the Workflow section of the Tutorial.

### Navigation

- index
- next |
- django-inviteme-form v1.0a documentation »